@@ -35,6 +35,7 @@
 
 #include "src/util.h"
 #include "src/iwd.h"
+#include "src/module.h"
 #include "src/common.h"
 #include "src/device.h"
 #include "src/watchlist.h"
@@ -56,6 +57,8 @@
 
 static struct l_queue *station_list;
 static uint32_t netdev_watch;
+static uint32_t mfp_setting;
+static bool anqp_disabled;
 
 struct station {
 	enum station_state state;
@@ -506,7 +509,6 @@ static bool station_start_anqp(struct station *station, struct network *network,
 	uint8_t anqp[256];
 	uint8_t *ptr = anqp;
 	struct anqp_entry *entry;
-	bool anqp_disabled = true;
 
 	if (!bss->hs20_capable)
 		return false;
@@ -515,9 +517,6 @@ static bool station_start_anqp(struct station *station, struct network *network,
 	if (network_get_info(network))
 		return false;
 
-	l_settings_get_bool(iwd_get_config(), "General", "disable_anqp",
-				&anqp_disabled);
-
 	if (anqp_disabled) {
 		l_debug("Not querying AP for ANQP data (disabled)");
 		return false;
@@ -652,10 +651,13 @@ static void station_reconnect(struct station *station);
 
 static void station_handshake_event(struct handshake_state *hs,
 					enum handshake_event event,
-					void *event_data, void *user_data)
+					void *user_data, ...)
 {
 	struct station *station = user_data;
 	struct network *network = station->connected_network;
+	va_list args;
+
+	va_start(args, user_data);
 
 	switch (event) {
 	case HANDSHAKE_EVENT_STARTED:
@@ -668,13 +670,14 @@ static void station_handshake_event(struct handshake_state *hs,
 		network_sync_psk(network);
 		break;
 	case HANDSHAKE_EVENT_FAILED:
-		netdev_handshake_failed(hs, l_get_u16(event_data));
+		netdev_handshake_failed(hs, va_arg(args, int));
 		break;
 	case HANDSHAKE_EVENT_REKEY_FAILED:
 		station_reconnect(station);
 		break;
 	case HANDSHAKE_EVENT_COMPLETE:
 	case HANDSHAKE_EVENT_SETTING_KEYS_FAILED:
+	case HANDSHAKE_EVENT_EAP_NOTIFY:
 		/*
 		 * currently we dont care about any other events. The
 		 * netdev_connect_cb will notify us when the connection is
@@ -682,6 +685,8 @@ static void station_handshake_event(struct handshake_state *hs,
 		 */
 		break;
 	}
+
+	va_end(args);
 }
 
 static bool station_has_erp_identity(struct network *network)
@@ -733,11 +738,9 @@ static int station_build_handshake_rsn(struct handshake_state *hs,
 	bool add_mde = false;
 	bool fils_hint = false;
 
-	const struct l_settings *settings = iwd_get_config();
 	struct ie_rsn_info bss_info;
 	uint8_t rsne_buf[256];
 	struct ie_rsn_info info;
-	uint32_t mfp_setting;
 	uint8_t *ap_ie;
 
 	memset(&info, 0, sizeof(info));
@@ -785,22 +788,6 @@ static int station_build_handshake_rsn(struct handshake_state *hs,
 		goto build_ie;
 	}
 
-	if (!l_settings_get_uint(settings, "General",
-					"management_frame_protection",
-					&mfp_setting)) {
-		if (!l_settings_get_uint(settings, "General",
-				"ManagementFrameProtection", &mfp_setting)) {
-			mfp_setting = 1;
-		} else
-			l_warn("ManagementFrameProtection option is deprecated "
-				"use 'management_frame_protection'");
-	}
-
-	if (mfp_setting > 2) {
-		l_error("Invalid MFP value, using default of 1");
-		mfp_setting = 1;
-	}
-
 	switch (mfp_setting) {
 	case 0:
 		break;
@@ -1975,7 +1962,7 @@ static bool station_cannot_roam(struct station *station)
 	const struct l_settings *config = iwd_get_config();
 	bool disabled;
 
-	if (!l_settings_get_bool(config, "Scan", "disable_roaming_scan",
+	if (!l_settings_get_bool(config, "Scan", "DisableRoamingScan",
 								&disabled))
 		disabled = false;
 
@@ -3035,6 +3022,16 @@ void station_network_foreach(struct station *station,
 	l_hashmap_foreach(station->networks, network_foreach, &data);
 }
 
+struct l_queue *station_get_bss_list(struct station *station)
+{
+	return station->bss_list;
+}
+
+struct scan_bss *station_get_connected_bss(struct station *station)
+{
+	return station->connected_bss;
+}
+
 static struct station *station_create(struct netdev *netdev)
 {
 	struct station *station;
@@ -3197,6 +3194,22 @@ static int station_init(void)
 	l_dbus_register_interface(dbus_get_bus(), IWD_STATION_INTERFACE,
 					station_setup_interface,
 					station_destroy_interface, false);
+
+	if (!l_settings_get_uint(iwd_get_config(), "General",
+					"ManagementFrameProtection",
+					&mfp_setting))
+		mfp_setting = 1;
+
+	if (mfp_setting > 2) {
+		l_error("Invalid [General].ManagementFrameProtection value: %d,"
+				" using default of 1", mfp_setting);
+		mfp_setting = 1;
+	}
+
+	if (!l_settings_get_bool(iwd_get_config(), "General", "DisableANQP",
+				&anqp_disabled))
+		anqp_disabled = true;
+
 	return true;
 }
 
